package main

import (
	"encoding/json"
	"fmt"
	"net/http"
	"os"

	"codeberg.org/thefederationinfo/nodeinfo-go"
	"github.com/tidwall/pretty"
)

func main() {
	// init cli
	if len(os.Args) != 2 {
		fmt.Printf("Usage: %s <domain>\n", os.Args[0])
		os.Exit(1)
	}

	// get arg
	domain := os.Args[1]

	// exec lib
	info, err := nodeinfo.QueryNode(domain,
		// demo how to use options
		nodeinfo.QueryOptionClient(&http.Client{
			CheckRedirect: func(req *http.Request, via []*http.Request) error {
				return http.ErrUseLastResponse
			},
		}))

	// handle error
	if err != nil {
		fmt.Printf("ERROR: %s\n", err)
		os.Exit(2)
	}

	// print info as json
	if info != nil {
		raw, _ := json.Marshal(info)
		fmt.Printf(string(pretty.Pretty(raw)))
	} else {
		fmt.Println("could not obtain info")
	}
}
