package nodeinfo

import (
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestFetcherDoMatrix(t *testing.T) {
	f := newFetcher("matrix.org")
	info, err := f.do()
	assert.NoError(t, err)
	if assert.NotNil(t, info) {
		assert.EqualValues(t, "Synapse", info.Software.Name)
		assert.EqualValues(t, "https://matrix-org.github.io/synapse/latest/", info.Software.Homepage)
		assert.Truef(t, len(info.Software.Version) != 0, "expect a version")
	}
}

func TestFetcherDoMastodon(t *testing.T) {
	f := newFetcher("chaos.social")
	info, err := f.do()
	assert.NoError(t, err)
	if assert.NotNil(t, info) {
		assert.EqualValues(t, "mastodon", info.Software.Name)
		assert.Truef(t, len(info.Software.Version) != 0, "expect a version")
		assert.EqualValues(t, []string{"activitypub"}, info.Protocols)
	}
}

func TestFetcherDoDiaspora(t *testing.T) {
	f := newFetcher("diasp.org")
	info, err := f.do()
	assert.NoError(t, err)
	if assert.NotNil(t, info) {
		assert.EqualValues(t, "diaspora", info.Software.Name)
		assert.Truef(t, len(info.Software.Version) != 0, "expect a version")
		assert.EqualValues(t, []string{"diaspora"}, info.Protocols)
		assert.NotNil(t, info.Metadata["camo"])
		assert.Nil(t, info.Metadata["random"])
	}
}

func TestFetcherDoObermui(t *testing.T) {
	f := newFetcher("obermui.de")
	info, err := f.do()
	assert.NoError(t, err)
	assert.NotNil(t, info)
}

func TestFetcherDoProsody(t *testing.T) {
	f := newFetcher("lurk.org")
	info, err := f.do()
	assert.NoError(t, err)
	assert.NotNil(t, info)
	assert.EqualValues(t, "Prosody", info.Software.Name)
	assert.EqualValues(t, []string{"xmpp"}, info.Protocols)
	assert.EqualValues(t, Services{Inbound: []string{"xmpp"}, Outbound: []string{"xmpp"}}, info.Services)
}

func TestFetcherDoEjabberd(t *testing.T) {
	f := newFetcher("xmpp.social")
	info, err := f.do()
	assert.NoError(t, err)
	assert.NotNil(t, info)
	assert.EqualValues(t, "ejabberd", info.Software.Name)
	assert.EqualValues(t, []string{"xmpp"}, info.Protocols)
	assert.EqualValues(t, Services{Inbound: []string{"xmpp"}, Outbound: []string{"xmpp"}}, info.Services)
}
